********************************************************************************
*	Program: Andrews_Stange_Analysis_Part1.do
*   
*   This program uses one data set:
*		student_data - is a student level data set which tracks
*			which tracks student's educational outcomes and includes
* 			their demographic information as well as the predicted earnings
*			associated with their major
*
*	It produces a dataset containing regression results:
*		descriptive_regression_results - is the saved output of a 
*			set of descriptive regressions by ventile (of the form:
*			reg `outcome' poor post `controls' (possibly for some subsamples)
********************************************************************************


local WORKDIR = ""
local DATAPATH =""
local OUTPATH = ""
clear all
log using "`", text replace

use "`DATAPATH'/student_data.dta", clear

	tempfile results_program
	tempname coef_program
	postfile `coef_program' program first_school major_group str40 outcome str40 variable str40 controls coeff se obs using `results_program', replace

	egen program = group(first_school major_group)
	sum program, d
	local max_p = r(max)
foreach p in numlist 1/max_p{
gen program_`p'=0
replace program_`p'_1=1 if program==`p'
}
	foreach p of numlist 1/`max_p' {


		gen enroll_p = program==`p'
		
		qui sum first_school if program==`p'
		local first_school = r(max)
		qui sum major_group if program==`p'
		local major_group = r(max)	
		
		qui sum enroll_p if post==0
		local enroll_mean = r(mean) 
		qui sum enroll_p if poor==0 & post==0
		local enroll_mean_nonpoor = r(mean)
		qui sum enroll_p if poor==1 & post==0
		local enroll_mean_poor = r(mean)
		
		display "Program-specific estimates for program = `p' (first_school = `first_school', major_group = `major_group')"
		
		* No controls
		
		qui regress enroll_p time post poor post_poor if program==`p', cluster(cohort)
		local obs = e(N)
		
		local coeff = _b[post]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("post") ("None") (`coeff') (`se') (`obs')
		
		local coeff = _b[poor]
		local se = _se[poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("poor") ("None") (`coeff') (`se') (`obs')
		
		local coeff = _b[post_poor]
		local se = _se[post_poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("post_poor") ("None") (`coeff') (`se') (`obs')
		
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("premean_all") ("None") (`enroll_mean') (0) (`obs')
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("premean_nonpoor") ("None") (`enroll_mean_nonpoor') (0)	 (`obs')
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("premean_poor") ("None") (`enroll_mean_poor') (0) (`obs')
		
		* Test score controls
		
		qui regress enroll_p time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if program==`p', cluster(cohort)
		local obs = e(N)
		
		local coeff = _b[post]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("post") ("Test") (`coeff') (`se') (`obs')
		
		local coeff = _b[poor]
		local se = _se[poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("poor") ("Test") (`coeff') (`se') (`obs')
		
		local coeff = _b[post_poor]
		local se = _se[post_poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("post_poor") ("Test") (`coeff') (`se') (`obs')
		
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("premean_all") ("Test") (`enroll_mean') (0) (`obs')
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("premean_nonpoor") ("Test") (`enroll_mean_nonpoor') (0) (`obs')	 
		post `coef_program' (`p') (`first_school') (`major_group') ("enroll") ("premean_poor") ("Test") (`enroll_mean_poor') (0) (`obs')
		
		drop enroll_p
	}


foreach p of numlist 1/`max_p' {


		gen enroll_p = program==`p'
		
		qui sum first_school if program==`p'
		local first_school = r(max)
		qui sum major_group if program==`p'
		local major_group = r(max)	
		
		qui sum tuition if post==0
		local tuition_mean = r(mean) 
		qui sum tuition if poor==0 & post==0
		local tuition_mean_nonpoor = r(mean)
		qui sum tuition if poor==1 & post==0
		local enroll_mean_poor = r(mean)
		
		display "Program-specific estimates for program = `p' (first_school = `first_school', major_group = `major_group')"
		
		* No controls
		
		qui regress tuition time post poor post_poor  if program==`p', cluster(cohort)
		local obs = e(N)
		
		local coeff = _b[post]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("post") ("None") (`coeff') (`se') (`obs')
		
		local coeff = _b[poor]
		local se = _se[poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("poor") ("None") (`coeff') (`se') (`obs')
		
		local coeff = _b[post_poor]
		local se = _se[post_poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("post_poor") ("None") (`coeff') (`se') (`obs')
		
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("premean_all") ("None") (`enroll_mean') (0) (`obs')
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("premean_nonpoor") ("None") (`enroll_mean_nonpoor') (0)	 (`obs')
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("premean_poor") ("None") (`enroll_mean_poor') (0) (`obs')
		
		* Test score controls
		
		qui regress tuition time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if program==`p', cluster(cohort)
		local obs = e(N)
		
		local coeff = _b[post]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("post") ("Test") (`coeff') (`se') (`obs')
		
		local coeff = _b[poor]
		local se = _se[poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("poor") ("Test") (`coeff') (`se') (`obs')
		
		local coeff = _b[post_poor]
		local se = _se[post_poor]
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("post_poor") ("Test") (`coeff') (`se') (`obs')
		
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("premean_all") ("Test") (`enroll_mean') (0) (`obs')
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("premean_nonpoor") ("Test") (`enroll_mean_nonpoor') (0) (`obs')	 
		post `coef_program' (`p') (`first_school') (`major_group') ("tuition") ("premean_poor") ("Test") (`enroll_mean_poor') (0) (`obs')
		
		drop enroll_p
	}

	preserve
	postclose `coef_program'
	use `results_program', clear
	gen ci_hi = coeff + 1.96*se
	gen ci_lo = coeff - 1.96*se

	gen tstat = coeff/se
	gen pval = 100
	replace pval = 10 if abs(tstat) > 1.645
	replace pval = 5 if abs(tstat) > 1.960
	replace pval = 1 if abs(tstat) > 2.576

	gen str3 marker = "***" if pval == 1
	replace  marker = "**" if pval == 5
	replace  marker = "*" if pval == 10


save "`OUTPATH'/descriptive_regresions_results.dta", replace

restore, preserve

postfile `coef_program1' program first_school major_group str40 outcome coeff se obs using `results_program1', replace

local deptouts "totsal_perenroll totsal_perenroll_trim FTE_sal totfac_perenroll average_enrollment needgrant hb3015_amt pell_amt txgrant_amt tpeg_amt"

foreach q of numlist 1/`max_p' {
	foreach v of local deptouts{
		regress `v' time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math  if program==`p', cluster(cohort)
		local coeff = _b[poor]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') (coeff`coeff'poor) (`coeff') (`se') (`obs')

		local coeff = _b[post]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') (coeff`coeff'post) (`coeff') (`se') (`obs')

		local coeff = _b[post_poor]
		local se = _se[post]
		post `coef_program' (`p') (`first_school') (`major_group') (coeff`coeff'post_poor) (`coeff') (`se') (`obs')

	}
}

	postclose `coef_program1'
	use `results_program', clear
	gen ci_hi = coeff + 1.96*se
	gen ci_lo = coeff - 1.96*se

	gen tstat = coeff/se
	gen pval = 100
	replace pval = 10 if abs(tstat) > 1.645
	replace pval = 5 if abs(tstat) > 1.960
	replace pval = 1 if abs(tstat) > 2.576

	gen str3 marker = "***" if pval == 1
	replace  marker = "**" if pval == 5
	replace  marker = "*" if pval == 10
append using "`OUTPATH'/descriptive_regressions_results.dta"

save "`OUTPATH'/descriptive_regresions_results.dta", replace

restore, preserve


	postfile `coef_program2' ventile vent_type str40 outcome str40 variable str40 controls coeff se obs using `results_program2', replace


	local outs "raw demo test "

	foreach v of local outs{
		foreach q of numlist 1/20 {
			gen q_`v'_`q' = (vent_`v' == `q')
		}

		* No controls
		foreach q of numlist 1/20 {
			regress q_`v'_`q' time post poor post_poor , cluster(cohort)
			if `q' == 1 {
			outreg2 using "`OUTPATH'/descriptive_evidence_vent_`v'_`version'_full_sample.xls", excel replace dec(4) addtext(Ventile, `q', Controls, None) 
			}	
			if  `q' != 1 {
			outreg2 using "`OUTPATH'/descriptive_evidence_vent_`v'_`version'_full_sample.xls", excel append dec(4) addtext(Ventile, `q', Controls, None) 
			}	

			local coeff = _b[post]
			local se = _se[post]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post") ("None") (`coeff') (`se')
			
			local coeff = _b[poor]
			local se = _se[poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("poor") ("None") (`coeff') (`se')
			
			local coeff = _b[post_poor]
			local se = _se[post_poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post_poor") ("None") (`coeff') (`se')		
		}

		* Demog controls
		foreach q of numlist 1/20 {		
			regress q_`v'_`q' time post poor post_poor asian black white hispanic lep sex , cluster(cohort)
			
			local coeff = _b[post]
			local se = _se[post]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post") ("Demog") (`coeff') (`se')
			
			local coeff = _b[poor]
			local se = _se[poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("poor") ("Demog") (`coeff') (`se')
			
			local coeff = _b[post_poor]
			local se = _se[post_poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post_poor") ("Demog") (`coeff') (`se')	
		}

		* Test score controls
		foreach q of numlist 1/20 {	
			regress q_`v'_`q' time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math , cluster(cohort)
			
			local coeff = _b[post]
			local se = _se[post]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post") ("Test") (`coeff') (`se')
			
			local coeff = _b[poor]
			local se = _se[poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("poor") ("Test") (`coeff') (`se')
			
			local coeff = _b[post_poor]
			local se = _se[post_poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post_poor") ("Test") (`coeff') (`se')	
		}

		* App controls
		foreach q of numlist 1/20 {	
			regress q_`v'_`q' time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math `app_set', cluster(cohort)
			
			local coeff = _b[post]
			local se = _se[post]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post") ("App") (`coeff') (`se')
			
			local coeff = _b[poor]
			local se = _se[poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("poor") ("App") (`coeff') (`se')
			
			local coeff = _b[post_poor]
			local se = _se[post_poor]
			post `coef' (`q') ("vent_`v'") ("enroll") ("post_poor") ("App") (`coeff') (`se')
			

		}
	* HS Fixed effects
	foreach q of numlist 1/20 {	
		areg q_`v'_`q' time post poor post_poor asian black white hispanic lep sex scaled_reading scaled_math , cluster(cohort) absorb(campus)
		
		local coeff = _b[post]
		local se = _se[post]
		post `coef' (`q') ("vent_`v'") ("enroll") ("post") ("HS FE") (`coeff') (`se')
		
		local coeff = _b[poor]
		local se = _se[poor]
		post `coef' (`q') ("vent_`v'") ("enroll") ("poor") ("HS FE") (`coeff') (`se')
		
		local coeff = _b[post_poor]
		local se = _se[post_poor]
		post `coef' (`q') ("vent_`v'") ("enroll") ("post_poor") ("HS FE") (`coeff') (`se')
	}


	postclose `coef_program2'
	use `results_program', clear
	gen ci_hi = coeff + 1.96*se
	gen ci_lo = coeff - 1.96*se

	gen tstat = coeff/se
	gen pval = 100
	replace pval = 10 if abs(tstat) > 1.645
	replace pval = 5 if abs(tstat) > 1.960
	replace pval = 1 if abs(tstat) > 2.576

	gen str3 marker = "***" if pval == 1
	replace  marker = "**" if pval == 5
	replace  marker = "*" if pval == 10
	gen vent_testd1 = vent+.1
	gen vent_testd2 = vent+.2
	gen vent_testd3 = vent+.3
	gen vent_testd4 = vent+.4
	gen vent_t1 = vent + .15
	gen vent_t2 = vent + .3
	gen vent_t3 = vent + .45
	gen vent_t4 = vent + .6

append using "`OUTPATH'/descriptive_regressions_results.dta"

save "`OUTPATH'/descriptive_regresions_results.dta", replace

restore, preserve

