/*==============================================================================
Do-file name:  tuition_descriptives.do
Created: Oct 6, 2015 by P De Vlieger
Last Updated: Oct 6, 2015 by P De Vlieger
Author: P De Vlieger

==============================================================================*/

/*==============================================================================
Description: Get some descriptives on the tuition data. 

Uses: tuition_CIP_matches.dta. This dataset has an observation for each program
(institution X major) in each year. It was hand-collected by Kevin Stange and 
Jeongeun Kim from from course catalogs and archival sources and captured separately 
for each identifiable program (with a distinct tuition or fee), residency status, 
undergraduate level, academic year, entering cohort, and number of credit hours.
Price data was then converted to the CIP2 level for merging onto the THECB data.
Our tuition measure is "tuition14", which is the sticker price for in-state 
juniors taking 15 SCH in a given year
==============================================================================*/
clear
version 13
set mem 500m
set matsize 800
set more off
capture log close
set logtype text
set trace off
set niceness 4
pause off

********************************************************************************
*     
********************************************************************************


*** Import data and keep observations for which price data is available

    use tuition_CIP_matches.dta, clear
	keep if marker==1


* Figure 1A mean trend in tuition
label var tuition14 "Tuition Amount ($)"
label var cur_year "Year"
twoway (scatter tuition14 cur_year), title("Trends in Tuition (In-State Juniors, 15 SCH)") ///
       xlabel(2000(2)2010) xline(2003.5) scheme(s1mono) ylabel(1000(1000)6000)
graph export Figure1A_paper_trend_tuition14.pdf, replace	
	
* Figure 1B dispersion trend in tuition
preserve
  egen tuition_sd = sd(tuition14), by(cur_year)
  label var tuition_sd "Standard Deviation Tuition ($)"
  twoway (scatter tuition_sd cur_year), title("Standard Deviation of Tuition (Across Programs)") ///
         xlabel(2000(2)2010) xline(2003.5) scheme(s1mono) ylabel(200(100)700)
  graph export Figure1B_paper_trend_sd14.pdf, replace
restore


